@@ -1,4 +1,5 @@
 import json
+import base64
 from google.cloud import pubsub_v1
 
 
@@ -28,3 +29,15 @@ def publish_message(objects: list, project_id: str, topic_name: str) -> bool:
             raise Exception
 
     return True
+
+
+def read_pk(event) -> int:
+    """
+    Извлекает pk из сообщения Google Cloud Pub/Sub
+    :param event: Сообщения Google Cloud Pub/Sub
+    :return: Идентификатор обьекта API Core
+    """
+    message_bytes = base64.b64decode(event['data'])
+    message = json.loads(message_bytes)
+    pk = int(message['data']['message'])
+    return pk
